==> deal.ii_9.5.1.orig.tar.xz: deal.ii-9.5.1/AUTHORS.md <==
deal.II Authors
===============

deal.II is a global project. It is run by a group of principal developers.
Former developers with significant contributions in the past who are no
longer active, are listed under developers emeriti. A subset of the active
developers are administrators and responsible for the upkeep of the
technical infrastructure such as the website, discussion forums, and other
pieces. Finally, a large number of contributors have provided substantial
patches over the years. These groups are listed below.

Principal developers:
---------------------

 - Daniel Arndt, Oak Ridge National Laboratory, USA
 - Wolfgang Bangerth, Colorado State University, CO, USA
 - Marc Fehling, Colorado State University, CO, USA
 - Timo Heister, Clemson University, SC, USA
 - Luca Heltai, SISSA, Trieste, Italy
 - Martin Kronbichler, University of Augsburg, Germany
 - Matthias Maier, Texas A&M University, College Station, TX, USA
 - Peter Munch, University of Augsburg, Germany
 - Jean-Paul Pelteret, Independent Researcher, Germany
 - Bruno Turcksin, Oak Ridge National Laboratory, USA
 - David Wells, University of North Carolina, Chapel Hill, NC, USA

Developers emeriti:
-------------------

 - Denis Davydov, Independent Researcher, Germany
 - Ralf Hartmann, DLR, Germany
 - Guido Kanschat, Heidelberg University, Germany
 - Toby D. Young, Polish Academy of Sciences, Poland

Contributors:
-------------

 - Pasquale Africa
 - Ashna Aggarwal
 - Mihai Alexe
 - Moritz Allmaras
 - Fahad Alrashed
 - Giovanni Alzetta
 - Michael Anderson
 - Julian Andrej
 - Mathias Anselmann
 - Daniel Appel
 - Juan Carlos Araujo Cabarcas
 - Daniel Arndt
 - Rajat Arora
 - Arpit Babbar
 - Andrew Baker
 - Wolfgang Bangerth
 - Mauro Bardelloni
 - Nicolas Barnafi
 - Alistair Bentley
 - Maximilian Bergbauer
 - Kirana Bergstrom
 - Manaswinee Bezbaruah
 - Nistha Bhawsinka
 - Bruno Blais
 - Alexander Blank
 - Vishal Boddu
 - Andrea Bonito
 - Marco Borelli
 - Benjamin Brands
 - Claire Bruna-Rosso
 - Michele Bucelli
 - Till Budde
 - Markus Bürg
 - John Burnell
 - Krysztof Bzowski
 - Yong-Yong Cai
 - Marcus Calhoun-Lopez
 - Lucas Campos
 - Brian Carnes
 - Daniel Castanon Quiroz
 - David F. Castellanos
 - Fabian Castelli
 - Nicola Cavallini
 - Jordan Cazamias
 - Praveen Chandrashekar
 - Jie Cheng
 - Huimin Chen
 - Joshua Christopher
 - Ivan Christov
 - Pi-Yueh Chuang
 - Chih-Che Chueh
 - Emma Cinatl
 - Thomas ClevengerC.
 - Terry Cojean
 - Ester Comellas
 - Katherine Cosburn
 - Sam Cox
 - Cu Cui
 - Juliane Dannberg
 - Sambit Das
 - Andrew Davis
 - Denis Davydov
 - Elias Dejene
 - Nicola Demo
 - Chaitanya Dev
 - Ginkgo developers
 - Giovanni Di Ilio
 - Stefano Dominici
 - Nivesh Dommaraju
 - Brett Dong
 - Minh Do-Quang
 - Kevin Drzycimski
 - Kevin Dugan
 - Toni El Geitani Nehme
 - Luel Emishaw
 - Marco Engelhard
 - Patrick Esser
 - Anton Evgrafov
 - Marco Feder
 - Marc Fehling
 - Niklas Fehn
 - Emmanuel Ferdman
 - Isuru Fernando
 - Rebecca Fildes
 - Andreas Fink
 - Corbin Foucart
 - Menno Fraters
 - Johannes Friedlein
 - Jörg Frohne
 - Anian Fuchs
 - Sebastian Fuchs
 - Ivan Fumagalli
 - Andres Galindo
 - Vadim Gallyamov
 - Daniel Garcia-Sanchez
 - Rene Gassmoeller
 - Joscha Gedicke
 - Thomas Geenen
 - Martin Genet
 - Melanie Gerault
 - Arezou Ghesmati
 - Nicola Giuliani
 - Brandon Gleeson
 - Anne Glerum
 - Christoph Goering
 - Robin Goermer
 - Christian Goll
 - Sebastian Gonzalez-Pintor
 - Krishnakumar Gopalakrishnan
 - Alexander Grayver
 - Ryan Grove
 - Felix Gruber
 - Olivier Guevremont
 - Diane Guignard
 - Maien Hamed
 - Joshua Hanophy
 - Logan Harbour
 - Jake Harmon
 - Michael Harmon
 - Graham Harper
 - Mohammed Hassan
 - Nicole Hayes
 - Bang He
 - Eric Heien
 - Christoph Heiniger
 - Johannes Heinz
 - Timo Heister
 - Luca Heltai
 - Michael F. Herbst
 - Quang Hoang
 - Jiuhua Hu
 - Dakshina Ilangovan
 - Lise-Marie Imbert-Gerard
 - Samuel Imfeld
 - Sean Ingimarson
 - Vladimir Ivannikov
 - Bärbel Janssen
 - Manu Jayadharan
 - Armin Ghajar Jazi
 - Pengfei Jia
 - Tao Jin
 - Xing Jin
 - Daniel Jodlbauer
 - Stefan Kaessmair
 - Marie Kajan
 - Christoph Kammer
 - Guido Kanschat
 - Justin Kauffman
 - Oliver Kayser-Herold
 - Vishal Kenchan
 - Andreas Kergassner
 - Eldar Khattatov
 - Seungil Kim
 - Sebastian Kinnewig
 - Benjamin Shelton Kirk
 - Angela Klewinghaus
 - Ingo Kligge
 - Alexander Knieps
 - Uwe Köcher
 - Alex Kokomov
 - Joachim Kopp
 - Katharina Kormann
 - Lukas Korous
 - Aslan Kosakian
 - Adam Kosik
 - Giorgos Kourakos
 - Oleh Krehel
 - Kurt Kremitzki
 - Martin Kronbichler
 - Paul Kuberry
 - Paras Kumar
 - Dustin Kumor
 - Ross Kynch
 - Konstantin Ladutenko
 - Charu Lata
 - Damien Lebrun-Grandie
 - Adam Lee
 - Tobias Leicht
 - Wenyu Lei
 - Zhou Lei
 - Tulio Ligneul
 - Yan Li
 - Karl Ljungkvist
 - Vijay Mahadevan
 - Matthias Maier
 - Katrin Mang
 - Cataldo Manigrasso
 - Nils Margenberg
 - Mae Markowski
 - Alberto F. Martin
 - Andre Massing
 - Jonathan Matthews
 - Andrew McBride
 - Stefan Meggendorfer
 - Mathias Mentler
 - Craig Michoski
 - Franco Milicchio
 - Scott Miller
 - Phillip Mobley
 - Andrea Mola
 - Adriana Morales Miranda
 - Nils Much
 - Helmut Müller
 - Peter Munch
 - Jose Javier Munoz Criollo
 - Bob Myhill
 - Stefan Nauber
 - Pratik Nayak
 - David Neckels
 - Dragan Nikolic
 - Emily Novak
 - Justin O'Connor
 - Omotayo Omosebi
 - Santiago Ospina
 - Alexey Ozeritskiy
 - Vaibhav Palkar
 - Spencer Patty
 - Judith Pauen
 - Daniel Paukner
 - M. Sebastian Pauletti
 - Luz Paz
 - Jean-Paul Pelteret
 - Rebecca Pereira
 - Jonathan Perry-Houts
 - Dirk Peschka
 - Jan Philipp
 - Jonathan Pitt
 - Giuseppe Pitton
 - Geneva Porter
 - Fernando Posada
 - Vachan Potluri
 - IV Powell, Adam
 - Raghunandan Pratoori
 - Laura Prieto Saavedra
 - Florian Prill
 - Sebastian Proell
 - Simon Puchert
 - E. Gerry Puckett
 - Andreas Putz
 - Lei Qiao
 - Ce Qin
 - Manuel Quezada de Luna
 - Michael Rapson
 - Reza Rastak
 - Roland Richter
 - Thomas Richter
 - Gennadiy Rishin
 - Jonathan Robey
 - Angel Rodriguez
 - Oleg Rogozin
 - Jose E. Roman
 - Irabiel Romero
 - Ian Rose
 - Julian Roth
 - Shiva Rudraraju
 - Matthew Russell
 - Mayank Sabharwal
 - Abner Salgado-Gonzalez
 - Andrew Salmon
 - Ali Samii
 - Tonatiuh Sanchez-Vizuet
 - Alberto Sartori
 - Michael Schlottke-Lakemper
 - Christoph Schmidt
 - Anna Schneebeli
 - David Schneider
 - Svenja Schoeder
 - Raphael Schoof
 - Jan Schrage
 - Magdalena Schreter
 - Ralf B. Schulz
 - Richard Schussnig
 - Nils Schween
 - Ahmad Shahba
 - Daniel Shapero
 - Natasha S. Sharma
 - Jason Sheldon
 - Doug Shi-Dong
 - Ben Shields
 - Konrad Simon
 - Dominic Soldner
 - Florian Sonner
 - Stephanie Sparks
 - Michael Stadler
 - Sebastian Stark
 - Jan Stebel
 - Martin Steigemann
 - Simon Sticko
 - Franz-Theo Suttmeier
 - Oliver Sutton
 - Habib Talavatifard
 - Zhen Tao
 - Buğrahan Temür
 - Marco Tezzele
 - Jan Philipp Thiele
 - Ben Thompson
 - Jihuan Tian
 - Malhar Tidke
 - Ignacio Tomas
 - Christophe Trophime
 - Sara Tro
 - Bruno Turcksin
 - Ferdinand Vanmaele
 - Antoni Vidal
 - Kuljit S. Virk
 - Heikki Virtanen
 - Jiaxin Wang
 - Kainan Wang
 - Yaqi Wang
 - Yuxiang Wang
 - Zhuoran Wang
 - Ivy Weber
 - Xiaoyu Wei
 - David Wells
 - Peter Westerbaan
 - Sven Wetterauer
 - Daniel Weygand
 - Joshua White
 - Michał Wichrowski
 - Niklas Wik
 - Julius Witte
 - Winnifried Wollner
 - Christian Wülker
 - Ming Yang
 - Jaeryun Yim
 - Toby D. Young
 - Feimi Yu
 - Vladimir Yushutin
 - Stefano Zampini
 - Mario Zepeda Aguilar
 - Jiaqi Zhang
 - Wenjuan Zhang
 - Liang Zhao
 - Victor Zheng
 - Weixiong Zheng
 - Yuhan Zhou
 - Valentin Zingan

==> deal.ii_9.6.2.orig.tar.xz: deal.ii-9.6.2/AUTHORS.md <==
deal.II Authors
===============

deal.II is a global project. It is run by a group of principal developers.
Former developers with significant contributions in the past who are no
longer active, are listed under developers emeriti. A subset of the active
developers are administrators and responsible for the upkeep of the
technical infrastructure such as the website, discussion forums, and other
pieces. Finally, a large number of contributors have provided substantial
patches over the years. These groups are listed below.

Principal developers:
---------------------

 - Daniel Arndt, Oak Ridge National Laboratory, USA
 - Wolfgang Bangerth, Colorado State University, CO, USA
 - Bruno Blais, Polytechnique Montréal, Canada
 - Marc Fehling, Charles University, Czech Republic
 - Rene Gassmoeller, University of Florida, FL, USA
 - Timo Heister, Clemson University, SC, USA
 - Luca Heltai, University of Pisa, Italy
 - Martin Kronbichler, Ruhr University Bochum, Germany
 - Matthias Maier, Texas A&M University, College Station, TX, USA
 - Peter Munch, University of Augsburg, Germany
 - Jean-Paul Pelteret, Independent Researcher, Germany
 - Bruno Turcksin, Oak Ridge National Laboratory, USA
 - David Wells, University of North Carolina, Chapel Hill, NC, USA

Developers emeriti:
-------------------

 - Denis Davydov, Independent Researcher, Germany
 - Ralf Hartmann, DLR, Germany
 - Guido Kanschat, Heidelberg University, Germany
 - Toby D. Young, Polish Academy of Sciences, Poland

Contributors:
-------------

 - Laryssa Abdala
 - Pasquale Africa
 - Ashna Aggarwal
 - Mihai Alexe
 - Moritz Allmaras
 - Fahad Alrashed
 - Giovanni Alzetta
 - Michael Anderson
 - Julian Andrej
 - Mathias Anselmann
 - Daniel Appel
 - Juan Carlos Araujo Cabarcas
 - Daniel Arndt
 - Rajat Arora
 - Arpit Babbar
 - Andrew Baker
 - Abbas Ballout
 - Wolfgang Bangerth
 - Mauro Bardelloni
 - Nicolas Barnafi
 - Alistair Bentley
 - Maximilian Bergbauer
 - Kirana Bergstrom
 - Manaswinee Bezbaruah
 - Nistha Bhawsinka
 - Bruno Blais
 - Alexander Blank
 - Vishal Boddu
 - Andrea Bonito
 - Marco Borelli
 - Benjamin Brands
 - Julian Brotz
 - Claire Bruna-Rosso
 - Michele Bucelli
 - Till Budde
 - John Burnell
 - Krysztof Bzowski
 - Markus Bürg
 - Yong-Yong Cai
 - Marcus Calhoun-Lopez
 - Lucas Campos
 - Brian Carnes
 - Daniel Castanon Quiroz
 - David F. Castellanos
 - Fabian Castelli
 - Nicola Cavallini
 - Jordan Cazamias
 - Praveen Chandrashekar
 - Huimin Chen
 - Jie Cheng
 - Joshua Christopher
 - Ivan Christov
 - Pi-Yueh Chuang
 - Chih-Che Chueh
 - Emma Cinatl
 - Thomas C. Clevenger
 - Terry Cojean
 - Ester Comellas
 - Katherine Cosburn
 - Sam Cox
 - Cu Cui
 - Juliane Dannberg
 - Sambit Das
 - Andrew Davis
 - Denis Davydov
 - Elias Dejene
 - Nicola Demo
 - Chaitanya Dev
 - Ginkgo developers
 - Giovanni Di Ilio
 - Minh Do-Quang
 - Stefano Dominici
 - Nivesh Dommaraju
 - Brett Dong
 - Kevin Drzycimski
 - Kevin Dugan
 - Toni El Geitani Nehme
 - Luel Emishaw
 - Marco Engelhard
 - Patrick Esser
 - Anton Evgrafov
 - Marco Feder
 - Marc Fehling
 - Niklas Fehn
 - Emmanuel Ferdman
 - Isuru Fernando
 - Rebecca Fildes
 - Andreas Fink
 - Corbin Foucart
 - Menno Fraters
 - Johannes Friedlein
 - Jörg Frohne
 - Anian Fuchs
 - Sebastian Fuchs
 - Ivan Fumagalli
 - Andres Galindo
 - Vadim Gallyamov
 - Daniel Garcia-Sanchez
 - Rene Gassmoeller
 - Joscha Gedicke
 - Thomas Geenen
 - Martin Genet
 - Melanie Gerault
 - Arezou Ghesmati
 - Nicola Giuliani
 - Brandon Gleeson
 - Anne Glerum
 - Christoph Goering
 - Robin Goermer
 - Christian Goll
 - Sebastian Gonzalez-Pintor
 - Krishnakumar Gopalakrishnan
 - Alexander Grayver
 - Ryan Grove
 - Felix Gruber
 - Olivier Guevremont
 - Diane Guignard
 - Maien Hamed
 - Joshua Hanophy
 - Logan Harbour
 - Jake Harmon
 - Michael Harmon
 - Graham Harper
 - Mohammed Hassan
 - Nicole Hayes
 - Bang He
 - Eric Heien
 - Christoph Heiniger
 - Johannes Heinz
 - Timo Heister
 - Luca Heltai
 - Michael F. Herbst
 - Quang Hoang
 - Jiuhua Hu
 - Dakshina Ilangovan
 - Lise-Marie Imbert-Gerard
 - Samuel Imfeld
 - Sean Ingimarson
 - Vladimir Ivannikov
 - Bärbel Janssen
 - Manu Jayadharan
 - Armin Ghajar Jazi
 - Pengfei Jia
 - Tao Jin
 - Xing Jin
 - Yimin Jin
 - Daniel Jodlbauer
 - Stefan Kaessmair
 - Marie Kajan
 - Christoph Kammer
 - Guido Kanschat
 - Justin Kauffman
 - Oliver Kayser-Herold
 - Vishal Kenchan
 - Andreas Kergassner
 - Eldar Khattatov
 - Seungil Kim
 - Sebastian Kinnewig
 - Benjamin Shelton Kirk
 - Angela Klewinghaus
 - Ingo Kligge
 - Alexander Knieps
 - Alex Kokomov
 - Joachim Kopp
 - Katharina Kormann
 - Lukas Korous
 - Aslan Kosakian
 - Adam Kosik
 - Giorgos Kourakos
 - Oleh Krehel
 - Kurt Kremitzki
 - Martin Kronbichler
 - Paul Kuberry
 - Paras Kumar
 - Dustin Kumor
 - Ross Kynch
 - Uwe Köcher
 - Konstantin Ladutenko
 - Charu Lata
 - Damien Lebrun-Grandie
 - Adam Lee
 - Wenyu Lei
 - Zhou Lei
 - Tobias Leicht
 - Yan Li
 - Tulio Ligneul
 - Karl Ljungkvist
 - Sébastien Loriot
 - Vijay Mahadevan
 - Matthias Maier
 - Katrin Mang
 - Cataldo Manigrasso
 - Nils Margenberg
 - Mae Markowski
 - Alberto F. Martin
 - Andre Massing
 - Jonathan Matthews
 - Andrew McBride
 - Stefan Meggendorfer
 - Mathias Mentler
 - Craig Michoski
 - Franco Milicchio
 - Scott Miller
 - Phillip Mobley
 - Andrea Mola
 - Adriana Morales Miranda
 - Nils Much
 - Abdullah Mujahid
 - Peter Munch
 - Jose Javier Munoz Criollo
 - Bob Myhill
 - Helmut Müller
 - Stefan Nauber
 - Pratik Nayak
 - David Neckels
 - Dragan Nikolic
 - Emily Novak
 - Justin O'Connor
 - Omotayo Omosebi
 - Santiago Ospina
 - Alexey Ozeritskiy
 - Vaibhav Palkar
 - Paul A. Patience
 - Spencer Patty
 - Judith Pauen
 - Daniel Paukner
 - M. Sebastian Pauletti
 - Luz Paz
 - Jean-Paul Pelteret
 - Rebecca Pereira
 - Jonathan Perry-Houts
 - Dirk Peschka
 - Jan Philipp
 - Jonathan Pitt
 - Giuseppe Pitton
 - Geneva Porter
 - Fernando Posada
 - Vachan Potluri
 - Adam Powell
 - Raghunandan Pratoori
 - Laura Prieto Saavedra
 - Florian Prill
 - Sebastian Proell
 - Simon Puchert
 - E. Gerry Puckett
 - Andreas Putz
 - Lei Qiao
 - Ce Qin
 - Manuel Quezada de Luna
 - Hendrik Ranocha
 - Michael Rapson
 - Reza Rastak
 - Johannes Resch
 - Roland Richter
 - Thomas Richter
 - Gennadiy Rishin
 - Andreas Ritthaler
 - Jonathan Robey
 - Angel Rodriguez
 - Oleg Rogozin
 - Jose E. Roman
 - Irabiel Romero
 - Ian Rose
 - Julian Roth
 - Shiva Rudraraju
 - Matthew Russell
 - Mayank Sabharwal
 - Abner Salgado-Gonzalez
 - Andrew Salmon
 - Ali Samii
 - Tonatiuh Sanchez-Vizuet
 - Alberto Sartori
 - Malik Scheifinger
 - Michael Schlottke-Lakemper
 - Christoph Schmidt
 - Anna Schneebeli
 - David Schneider
 - Svenja Schoeder
 - Raphael Schoof
 - Jan Schrage
 - Magdalena Schreter
 - Ralf B. Schulz
 - Richard Schussnig
 - Nils Schween
 - Kyle Schwiebert
 - Ahmad Shahba
 - Daniel Shapero
 - Natasha S. Sharma
 - Jason Sheldon
 - Doug Shi-Dong
 - Ben Shields
 - Konrad Simon
 - Simranjeet Singh
 - Dominic Soldner
 - Florian Sonner
 - Stephanie Sparks
 - Michael Stadler
 - Sebastian Stark
 - Jan Stebel
 - Martin Steigemann
 - Simon Sticko
 - Dominik Still
 - Franz-Theo Suttmeier
 - Oliver Sutton
 - Habib Talavatifard
 - Zhen Tao
 - Buğrahan Temür
 - Marco Tezzele
 - Jan Philipp Thiele
 - Thierry Thomas
 - Ben Thompson
 - Jihuan Tian
 - Malhar Tidke
 - Ignacio Tomas
 - Sara Tro
 - Christophe Trophime
 - Bruno Turcksin
 - Ferdinand Vanmaele
 - Antoni Vidal
 - Vinayak Vijay
 - Kuljit S. Virk
 - Heikki Virtanen
 - Jiaxin Wang
 - Kainan Wang
 - Yaqi Wang
 - Yuxiang Wang
 - Zhuoran Wang
 - Ivy Weber
 - Xiaoyu Wei
 - David Wells
 - Peter Westerbaan
 - Sven Wetterauer
 - Daniel Weygand
 - Joshua White
 - Michał Wichrowski
 - Thomas Wick
 - Simon Wiesheier
 - Niklas Wik
 - Julius Witte
 - Winnifried Wollner
 - Christian Wülker
 - Ming Yang
 - Jaeryun Yim
 - Chengjiang Yin
 - Toby D. Young
 - Feimi Yu
 - Vladimir Yushutin
 - Stefano Zampini
 - Mario Zepeda Aguilar
 - Jiaqi Zhang
 - Wenjuan Zhang
 - Liang Zhao
 - Victor Zheng
 - Weixiong Zheng
 - Yuhan Zhou
 - Valentin Zingan
